from .funfacts import fun_fact
from .smalltalk import smallTalk
from .pickuplines import pickUpLine
from .banter import banter
from .compliments import compliment

__all__ = ["fun_fact", "smallTalk", "pickUpLine", "banter", "compliment"] # append your function to this list
__version__ = "0.0.1"  
